@@ -1,4 +1,4 @@
-#! /usr/bin/python
+#! /usr/bin/python3
 # -*- python -*-
 # -*- coding: utf-8 -*-
 #
@@ -25,6 +25,5 @@ Abstractions to extract information from the Linux kernel /proc files.
 __author__ = "Arnaldo Carvalho de Melo <acme@redhat.com>"
 __license__ = "GPLv2 License"
 
-from procfs import *
-from sysctl import *
-from utilist import *
+from .procfs import *
+from .utilist import *
